from collections.abc import Generator
from pathlib import Path

import libzfs


class ZFSHandler:
    def __init__(self) -> None:
        self.fs = "zfs"

    async def get_hardlinks(self, path: Path) -> Generator:
        path = path.resolve().absolute()
        inode = path.stat().st_ino

        zfs = libzfs.ZFS()
        dataset = zfs.get_dataset_by_path(str(path))
        if dataset is not None:
            pool = dataset.pool
            filesystem = dataset.filesystem
            fs = pool.open(filesystem)

            for snapshot in fs.snapshots():
                for entry in snapshot.ls(str(path)):
                    if entry.inode() == inode:
                        yield Path(entry.path())
